@@ -264,11 +264,6 @@ func run() error {
 		return err
 	}
 
-	if (listOptions.ShouldListTasks()) && flags.silent {
-		e.ListTaskNames(flags.listAll)
-		return nil
-	}
-
 	if err := e.Setup(); err != nil {
 		return err
 	}
@@ -279,6 +274,10 @@ func run() error {
 		return nil
 	}
 
+	if (listOptions.ShouldListTasks()) && flags.silent {
+		return e.ListTaskNames(flags.listAll)
+	}
+
 	if listOptions.ShouldListTasks() {
 		foundTasks, err := e.ListTasks(listOptions)
 		if err != nil {
@@ -291,7 +290,7 @@ func run() error {
 	}
 
 	var (
-		calls   []ast.Call
+		calls   []*ast.Call
 		globals *ast.Vars
 	)
 
@@ -304,7 +303,7 @@ func run() error {
 
 	// If there are no calls, run the default task instead
 	if len(calls) == 0 {
-		calls = append(calls, ast.Call{Task: "default"})
+		calls = append(calls, &ast.Call{Task: "default"})
 	}
 
 	globals.Set("CLI_ARGS", ast.Var{Value: cliArgs})
