@@ -4,6 +4,8 @@ import (
 	"fmt"
 	"net/http"
 	"time"
+
+	"github.com/Masterminds/semver/v3"
 )
 
 // TaskfileNotFoundError is returned when no appropriate Taskfile is found when
@@ -105,49 +107,60 @@ func (err *TaskfileNotSecureError) Code() int {
 	return CodeTaskfileNotSecure
 }
 
-// TaskfileCacheNotFound is returned when the user attempts to use an offline
+// TaskfileCacheNotFoundError is returned when the user attempts to use an offline
 // (cached) Taskfile but the files does not exist in the cache.
-type TaskfileCacheNotFound struct {
+type TaskfileCacheNotFoundError struct {
 	URI string
 }
 
-func (err *TaskfileCacheNotFound) Error() string {
+func (err *TaskfileCacheNotFoundError) Error() string {
 	return fmt.Sprintf(
 		`task: Taskfile %q was not found in the cache. Remove the --offline flag to use a remote copy or download it using the --download flag`,
 		err.URI,
 	)
 }
 
-func (err *TaskfileCacheNotFound) Code() int {
+func (err *TaskfileCacheNotFoundError) Code() int {
 	return CodeTaskfileCacheNotFound
 }
 
-// TaskfileVersionNotDefined is returned when the user attempts to run a
-// Taskfile that does not contain a Taskfile schema version key.
-type TaskfileVersionNotDefined struct {
-	URI string
+// TaskfileVersionCheckError is returned when the user attempts to run a
+// Taskfile that does not contain a Taskfile schema version key or if they try
+// to use a feature that is not supported by the schema version.
+type TaskfileVersionCheckError struct {
+	URI           string
+	SchemaVersion *semver.Version
+	Message       string
 }
 
-func (err *TaskfileVersionNotDefined) Error() string {
+func (err *TaskfileVersionCheckError) Error() string {
+	if err.SchemaVersion == nil {
+		return fmt.Sprintf(
+			`task: Missing schema version in Taskfile %q`,
+			err.URI,
+		)
+	}
 	return fmt.Sprintf(
-		`task: Taskfile %q does not contain a schema version key`,
+		"task: Invalid schema version in Taskfile %q:\nSchema version (%s) %s",
 		err.URI,
+		err.SchemaVersion.String(),
+		err.Message,
 	)
 }
 
-func (err *TaskfileVersionNotDefined) Code() int {
-	return CodeTaskfileVersionNotDefined
+func (err *TaskfileVersionCheckError) Code() int {
+	return CodeTaskfileVersionCheckError
 }
 
-// TaskfileNetworkTimeout is returned when the user attempts to use a remote
+// TaskfileNetworkTimeoutError is returned when the user attempts to use a remote
 // Taskfile but a network connection could not be established within the timeout.
-type TaskfileNetworkTimeout struct {
+type TaskfileNetworkTimeoutError struct {
 	URI          string
 	Timeout      time.Duration
 	CheckedCache bool
 }
 
-func (err *TaskfileNetworkTimeout) Error() string {
+func (err *TaskfileNetworkTimeoutError) Error() string {
 	var cacheText string
 	if err.CheckedCache {
 		cacheText = " and no offline copy was found in the cache"
@@ -158,6 +171,6 @@ func (err *TaskfileNetworkTimeout) Error() string {
 	)
 }
 
-func (err *TaskfileNetworkTimeout) Code() int {
+func (err *TaskfileNetworkTimeoutError) Code() int {
 	return CodeTaskfileNetworkTimeout
 }
